var config = {
	"modes":[
		{key:"abap", name:"ABAP"},
		{key:"abc", name:"ABC"},
		{key:"actionscript", name:"ActionScript"},
		{key:"ada", name:"ADA"},
		{key:"apache_conf", name:"Apache Conf"},
		{key:"asciidoc", name:"AsciiDoc"},
		{key:"assembly_x86", name:"Assembly x86"},
		{key:"autohotkey", name:"AutoHotKey"},
		{key:"batchfile", name:"BatchFile"},
		{key:"c_cpp", name:"C and C++"},
		{key:"c9search", name:"C9Search"},
		{key:"cirru", name:"Cirru"},
		{key:"clojure", name:"Clojure"},
		{key:"cobol", name:"Cobol"},
		{key:"coffee", name:"CoffeeScript"},
		{key:"coldfusion", name:"ColdFusion"},
		{key:"csharp", name:"C#"},
		{key:"css", name:"CSS"},
		{key:"curly", name:"Curly"},
		{key:"d", name:"D"},
		{key:"dart", name:"Dart"},
		{key:"diff", name:"Diff"},
		{key:"dockerfile", name:"Dockerfile"},
		{key:"dot", name:"Dot"},
		{key:"dummy", name:"Dummy"},
		{key:"dummysyntax", name:"DummySyntax"},
		{key:"eiffel", name:"Eiffel"},
		{key:"ejs", name:"EJS"},
		{key:"elixir", name:"Elixir"},
		{key:"elm", name:"Elm"},
		{key:"erlang", name:"Erlang"},
		{key:"forth", name:"Forth"},
		{key:"ftl", name:"FreeMarker"},
		{key:"gcode", name:"Gcode"},
		{key:"gherkin", name:"Gherkin"},
		{key:"gitignore", name:"Gitignore"},
		{key:"glsl", name:"Glsl"},
		{key:"gobstones", name:"Gobstones"},
		{key:"golang", name:"Go"},
		{key:"groovy", name:"Groovy"},
		{key:"haml", name:"HAML"},
		{key:"handlebars", name:"Handlebars"},
		{key:"haskell", name:"Haskell"},
		{key:"haxe", name:"haXe"},
		{key:"html", name:"HTML"},
		{key:"html_elixir", name:"HTML (Elixir)"},
		{key:"html_ruby", name:"HTML (Ruby)"},
		{key:"ini", name:"INI"},
		{key:"io", name:"Io"},
		{key:"jack", name:"Jack"},
		{key:"jade", name:"Jade"},
		{key:"java", name:"Java"},
		{key:"javascript", name:"JavaScript"},
		{key:"json", name:"JSON"},
		{key:"jsoniq", name:"JSONiq"},
		{key:"jsp", name:"JSP"},
		{key:"jsx", name:"JSX"},
		{key:"julia", name:"Julia"},
		{key:"latex", name:"LaTeX"},
		{key:"lean", name:"Lean"},
		{key:"less", name:"LESS"},
		{key:"liquid", name:"Liquid"},
		{key:"lisp", name:"Lisp"},
		{key:"livescript", name:"LiveScript"},
		{key:"logiql", name:"LogiQL"},
		{key:"lsl", name:"LSL"},
		{key:"lua", name:"Lua"},
		{key:"luapage", name:"LuaPage"},
		{key:"lucene", name:"Lucene"},
		{key:"makefile", name:"Makefile"},
		{key:"markdown", name:"Markdown"},
		{key:"mask", name:"Mask"},
		{key:"matlab", name:"MATLAB"},
		{key:"maze", name:"Maze"},
		{key:"mel", name:"MEL"},
		{key:"mushcode", name:"MUSHCode"},
		{key:"mysql", name:"MySQL"},
		{key:"nix", name:"Nix"},
		{key:"nsis", name:"NSIS"},
		{key:"objectivec", name:"Objective-C"},
		{key:"ocaml", name:"OCaml"},
		{key:"pascal", name:"Pascal"},
		{key:"perl", name:"Perl"},
		{key:"pgsql", name:"pgSQL"},
		{key:"php", name:"PHP"},
		{key:"powershell", name:"Powershell"},
		{key:"praat", name:"Praat"},
		{key:"prolog", name:"Prolog"},
		{key:"properties", name:"Properties"},
		{key:"protobuf", name:"Protobuf"},
		{key:"python", name:"Python"},
		{key:"r", name:"R"},
		{key:"razor", name:"Razor"},
		{key:"rdoc", name:"RDoc"},
		{key:"rhtml", name:"RHTML"},
		{key:"rst", name:"RST"},
		{key:"ruby", name:"Ruby"},
		{key:"rust", name:"Rust"},
		{key:"sass", name:"SASS"},
		{key:"scad", name:"SCAD"},
		{key:"scala", name:"Scala"},
		{key:"scheme", name:"Scheme"},
		{key:"scss", name:"SCSS"},
		{key:"sh", name:"SH"},
		{key:"sjs", name:"SJS"},
		{key:"smarty", name:"Smarty"},
		{key:"snippets", name:"snippets"},
		{key:"soy_template", name:"Soy Template"},
		{key:"space", name:"Space"},
		{key:"sql", name:"SQL"},
		{key:"sqlserver", name:"SQLServer"},
		{key:"stylus", name:"Stylus"},
		{key:"svg", name:"SVG"},
		{key:"swift", name:"Swift"},
		{key:"tcl", name:"Tcl"},
		{key:"tex", name:"Tex"},
		{key:"text", name:"Text"},
		{key:"textile", name:"Textile"},
		{key:"toml", name:"Toml"},
		{key:"twig", name:"Twig"},
		{key:"typescript", name:"Typescript"},
		{key:"vala", name:"Vala"},
		{key:"vbscript", name:"VBScript"},
		{key:"velocity", name:"Velocity"},
		{key:"verilog", name:"Verilog"},
		{key:"vhdl", name:"VHDL"},
		{key:"wollok", name:"Wollok"},
		{key:"xml", name:"XML"},
		{key:"xquery", name:"XQuery"},
		{key:"yaml", name:"YAML"},
		{key:"django", name:"Django"},
	],
	"themegroups":[
		{"name":"bright",
		"themes":[
			{key:"chrome",name:"chrome"},
			{key:"clouds",name:"clouds"},
			{key:"crimson_editor",name:"crimson_editor"},
			{key:"dawn",name:"dawn"},
			{key:"dreamweaver",name:"dreamweaver"},
			{key:"eclipse",name:"eclipse"},
			{key:"github",name:"github"},
			{key:"solarized_light",name:"solarized_light"},
			{key:"textmate",name:"textmate"},
			{key:"tomorrow",name:"tomorrow"},
			{key:"xcode",name:"xcode"}
			]
		},
		{"name":"dark",
		"themes":[
			{key:"clouds_midnight",name:"clouds_midnight"},
			{key:"cobalt",name:"cobalt"},
			{key:"idle_fingers",name:"idle_fingers"},
			{key:"kr_theme",name:"kr_theme"},
			{key:"merbivore",name:"merbivore"},
			{key:"merbivore_soft",name:"merbivore_soft"},
			{key:"mono_industrial",name:"mono_industrial"},
			{key:"monokai",name:"monokai"},
			{key:"pastel_on_dark",name:"pastel_on_dark"},
			{key:"solarized_dark",name:"solarized_dark"},
			{key:"terminal",name:"terminal"},
			{key:"tomorrow_night",name:"tomorrow_night"},
			{key:"tomorrow_night_blue",name:"tomorrow_night_blue"},
			{key:"tomorrow_night_bright",name:"tomorrow_night_bright"},
			{key:"tomorrow_night_eighties",name:"tomorrow_night_eighties"},
			{key:"twilight",name:"twilight"},
			{key:"vibrant_ink",name:"vibrant_ink"}
			]
		}
	]
};